@@ -25,7 +25,7 @@ def run_func(**kwargs):
     config = kwargs.get('config', kwargs.get('__config__', None))
     user_funcs = {
         k: kwargs[k]
-        for k in ['on_init', 'on_bar', 'on_tick']
+        for k in ['on_init', 'on_bar', 'on_tick','on_order','on_trade','on_open','on_close']
         if k in kwargs
     }
 
@@ -34,19 +34,31 @@ def run_func(**kwargs):
 
 def __run(config, strategy_loader):
     try:
-
         environment = Environment(config)
+        if environment.config.logfile is not None and environment.config.logfile != '':
+            logutil.log2file(environment.config.logfile)
 
         ucontext = StrategyContext()
 
         event_bus = EventBus()
 
+        environment.scheduler = Scheduler(event_bus)
+
         environment.market_api = MarketApi(event_bus)
 
         environment.market_api.Init()
 
         environment.basicdata_api = BasicDataApi()
 
+        if environment.config.run_type == 'PAPER_TRADING':
+            environment.trade_api = PaperTradeApi(event_bus)
+            environment.trade_api.Init()
+        elif environment.config.run_type == 'LIVE_TRADING':
+            environment.trade_api = RealTradeApi(event_bus)
+            environment.trade_api.Init()
+        elif environment.config.run_type == 'BACKTEST':
+            raise Exception('BACKTEST is not support!')
+
         from copy import copy
 
         scope = copy(iqsopenapi.models.__dict__)
