@@ -7,7 +7,3 @@ class HeartBeatReq(RequestMessage):
     def __init__(self):
         """请求类型"""
         self.RequestType = RequestType.HeartBeat
-
-        
-    def ToDict(self):
-        return {"ReqID":self.ReqID,"RequestType":self.RequestType}
