@@ -9,43 +9,43 @@ class BarData(object):
     def __init__(self):
 
         """合约或股票代码名称"""
-        self.Symbol = ""
+        self.symbol = ""
 
         """交易所"""
-        self.Exchange = Exchange.UnKnow
+        self.exchange = Exchange.UnKnow
 
         """周期类型以秒计算"""
-        self.DataType = 0
+        self.bar_type = 0
 
         """时间"""
-        self.LocalTime = datetime.now()
+        self.local_time = datetime.now()
 
         """昨收"""
-        self.PreClosePx = 0.0
+        self.pre_close = 0.0
 
         """开盘价"""
-        self.OpenPx = 0.0
+        self.open = 0.0
 
         """最高价"""
-        self.HighPx = 0.0
+        self.high = 0.0
 
         """最低价"""
-        self.LowPx = 0.0
+        self.low = 0.0
 
         """收盘价"""
-        self.ClosePx = 0.0
+        self.close = 0.0
 
         """成交量"""
-        self.Volume = 0
+        self.volume = 0
 
         """成交额"""
-        self.Amount = 0.0      
+        self.turnover = 0.0      
 
         """持仓量"""
-        self.OpenInterest = 0
+        self.open_interest = 0
 
         """结算价"""
-        self.SettlementPx = 0.0  
+        self.settlement = 0.0  
 
 
         
