@@ -15,6 +15,9 @@ class PushQuoteSubscriber(object):
         self.__cfg = cfg
         self.__strategy_id = strategy_id
         self.__user_info = user
+        self.__recv_callback = cfg.recvCallback
+        cfg.recvCallback = self.__OnRecv
+        cfg.connectedCallback = self.__AuotSubscribe
         self.__wsClient = WebSocketClient(cfg)
 
     def Connect(self):
@@ -22,9 +25,6 @@ class PushQuoteSubscriber(object):
         if not self.__wsClient.Connect():
             self.__wirteError("connect failed!")
             return False
-        if not self.__SetAccountInfo():
-            self.__wirteError("subscribe failed!")
-            return False
         self.__wsClient.AutoHeartBeat()
         return True
 
@@ -55,10 +55,20 @@ class PushQuoteSubscriber(object):
         '''收到消息'''
         if not msg: return
         # 心跳消息直接返回
-        if msg.get("requestType") == ResponseType.HeartBeat.name: return
-        cfg = self.__cfg
-        if not cfg: return
-        cfg.recvCallback(msg)
+        if msg.get("responseType") == ResponseType.HeartBeat.name: return
+        call = self.__recv_callback
+        if not call: return
+        call(msg)
+
+    def __AuotSubscribe(self):
+        """自动订阅"""
+        try:
+            logger.debug("连接成功，开始推送验证信息...")
+            if not self.__SetAccountInfo():
+                self.__wirteError("subscribe failed!")
+            logger.debug("连接成功，推送验证信息完成")
+        except Exception as e:
+            logger.error(e)
 
     def __wirteError(self, error):
         '''写错误日志'''
