@@ -16,9 +16,7 @@ class RealTradeApiCore:
     """期货交易接口"""
 
     def __init__(self):
-        root_path = GetRootPath()
-        self.__root_path = root_path
-        dir = os.path.join(root_path, 'iqsopenapi/trade/realtrade/Supervision')
+        dir = os.path.join(os.path.dirname(__file__), 'Supervision')
         self.__supervision_helper = SupervisionHelper(dir)
         self.__passwordKey = 'password'
         self.__tradeTokenKey = 'tradeToken'
