@@ -3,6 +3,7 @@ import sys
 import time
 import logging
 from datetime import datetime
+import os
 
 logger = logging.getLogger('iqsopenapilogger')
 logger.setLevel(logging.INFO)
@@ -14,19 +15,14 @@ console_handler.setLevel(logging.INFO)
 console_handler.setFormatter(logformat)
 logger.addHandler(console_handler)
 
-__add_logfile = False
-
-
-def log2file():
-    global __add_logfile
-    if __add_logfile:
-        return
-
-    file_handler = logging.FileHandler('openapi_{}.log'.format(datetime.now().strftime("%Y%m%d%H%M%S")))
+def log2file(filename):
+    path = os.path.dirname(filename)
+    if not os.path.exists(path):
+        os.makedirs(path)
+    file_handler = logging.FileHandler(filename)
     file_handler.setLevel(logging.INFO)
     file_handler.setFormatter(logformat)
     logger.addHandler(file_handler)
-    __add_logfile = True
 
 if __name__ == '__main__':
     
